# -*- coding: utf-8 -*-

from ..utils import *


class bloco_0(TrackedAttributesClass):
    """Classe do Bloco 0"""

    class registro_0001(TrackedAttributesClass):
        """
        REGISTRO 0001: ABERTURA DO BLOCO 0
        Este registro deve ser gerado para abertura do Bloco 0 e indica se há informações previstas para este bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0001, self).__init__()
            self.REG = '0001'  # Texto fixo contendo.
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = '0'  # Indicador de movimento:0- Bloco com dados informados;1- Bloco sem
            # dados informados.
            self.registro_0100 = []
            self.registro_0140 = []
            self.registro_0150 = []
            self.registro_0190 = []
            self.registro_0200 = []
            self.registro_0300 = []
            self.registro_0305 = []
            self.registro_0400 = []
            self.registro_0450 = []
            self.registro_0460 = []
            self.registro_0500 = []
            self.registro_0600 = []
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'IND_MOV': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_0100(TrackedAttributesClass):
        """
        REGISTRO 0100: DADOS DO CONTABILISTA
        Registro utilizado para identificação do contabilista responsável pela escrituração fiscal
        do estabelecimento,
        mesmo que o contabilista seja funcionário da empresa ou prestador de serviço.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0100, self).__init__()
            self.REG = '0100'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = '1'
            self.NOME = ''  # Nome do contabilista
            self.CPF = ''  # Número de inscrição do contabilista no CPF.
            self.CRC = ''  # Número de inscrição do contabilista no Conselho Regional de
            # Contabilidade.
            self.CNPJ = ''  # Número de inscrição do escritório de contabilidade no CNPJ, se houver.
            self.CEP = ''  # Código de Endereçamento Postal.
            self.END = ''  # Logradouro e endereço do imóvel.
            self.NUM = ''  # Número do imóvel
            self.COMPL = ''  # Dados complementares do endereço.
            self.BAIRRO = ''  # Bairro em que o imóvel está situado.
            self.FONE = ''  # Número do telefone (DDD+FONE).
            self.FAX = ''  # Número do fax.
            self.EMAIL = ''  # Endereço do correio eletrônico.
            self.COD_MUN = ''  # Código do município, conforme tabela IBGE.
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NOME': {'tipo': 'C', 'tamanho': 100, 'fixa_tamanho': False},
                'CPF': {'tipo': 'N', 'tamanho': 11, 'fixa_tamanho': True},
                'CRC': {'tipo': 'C', 'tamanho': 15, 'fixa_tamanho': False},
                'CNPJ': {'tipo': 'N', 'tamanho': 14, 'fixa_tamanho': True},
                'CEP': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': True},
                'END': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'NUM': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                'COMPL': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'BAIRRO': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'FONE': {'tipo': 'C', 'tamanho': 10, 'fixa_tamanho': True},
                'FAX': {'tipo': 'C', 'tamanho': 10, 'fixa_tamanho': True},
                'EMAIL': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                'COD_MUN': {'tipo': 'N', 'tamanho': 7, 'fixa_tamanho': True}
            }
            self.fieldnames = ('REG', 'NOME', 'CPF', 'CRC', 'CNPJ', 'CEP', 'END', 'NUM', 'COMPL',
                               'BAIRRO', 'FONE', 'FAX', 'EMAIL', 'COD_MUN')
            self.formato = self.get_formato()

    class registro_0110(TrackedAttributesClass):
        """
        REGISTRO 0110: REGIMES DE APURAÇÃO DA CONTRIBUIÇÃO SOCIAL E DE APROPRIAÇÃO DE CRÉDITO
        Este registro tem por objetivo definir o regime de incidência a que se submete a pessoa
        jurídica (não-cumulativo, cumulativo ou ambos os regimes) no período da escrituração. No
        caso de sujeição ao regime não-cumulativo, será informado também o método de apropriação do
        crédito incidente sobre operações comuns a mais de um tipo de receita
        adotado pela pessoa jurídica para o ano-calendário.
        """

        _order = []

        def __init__(self):
            super(bloco_0.registro_0110, self).__init__()
            self.REG = '0110'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = '1'
            self.COD_INC_TRIB = ''
            self.IND_APRO_CRED = ''
            self.COD_TIPO_CONT = ''
            self.IND_REG_CUM = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_INC_TRIB': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},
                'IND_APRO_CRED': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},
                'COD_TIPO_CONT': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},
                'IND_REG_CUM': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},

            }
            self.fieldnames = ('REG', 'COD_INC_TRIB', 'IND_APRO_CRED', 'COD_TIPO_CONT',
                               'IND_REG_CUM')
            self.formato = self.get_formato()

    class registro_0111(TrackedAttributesClass):
        """
        REGISTRO 0111: TABELA DE RECEITA BRUTA MENSAL PARA FINS DE RATEIO DE CRÉDITOS COMUNS
        Este registro é de preenchimento obrigatório, sempre que for informado no Registro “0110”,
        Campo 03
        (IND_APRO_CRED), o indicador correspondente ao método do Rateio Proporcional com base na
        Receita Bruta
        (indicador “2”), na apuração de créditos vinculados a mais de um tipo de receita.

        """

        _order = []

        def __init__(self):
            super(bloco_0.registro_0111, self).__init__()
            self.REG = '0111'
            self.nivel_h = 3
            self.pai = '0110'
            self.ocorrencia = '1'
            self.REC_BRU_NCUM_TRIB_MI = ''
            self.REC_BRU_NCUM_NT_MI = ''
            self.REC_BRU_NCUM_EXP = ''
            self.REC_BRU_CUM = ''
            self.REC_BRU_TOTAL = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'REC_BRU_NCUM_TRIB_MI': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False,
                                         'decimal': 2},
                'REC_BRU_NCUM_NT_MI': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False,
                                       'decimal': 2},
                'REC_BRU_NCUM_EXP': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False,
                                     'decimal': 2},
                'REC_BRU_CUM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'REC_BRU_TOTAL': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
            }
            self.fieldnames = ('REG', 'REC_BRU_NCUM_TRIB_MI', 'REC_BRU_NCUM_NT_MI',
                               'REC_BRU_NCUM_EXP', 'REC_BRU_CUM', 'REC_BRU_TOTAL')
            self.formato = self.get_formato()

    class registro_0120(TrackedAttributesClass):
        """
        REGISTRO 0120: IDENTIFICAÇÃO DE PERÍODOS DISPENSADOS DA ESCRITURAÇÃO FISCAL DIGITAL DAS
        CONTRIBUIÇÕES – EFD-CONTRIBUIÇÕES
        Registro opcional, específico para a pessoa jurídica informar os meses em que não tenha
        realizado operações representativas de receitas auferidas ou recebidas, e operações com
        direito a crédito (ensejando a dispensa de transmissão de EFD-Contribuições nesses meses),
        a ser apresentado na escrituração referente ao período de apuração de dezembro de cada
        ano-calendário ou no mês em que ocorreu a extinção, incorporação, fusão e cisão total ou
        parcial. Referido registro ainda não está disponibilizado para preenchimento,
        """

        _order = []

        def __init__(self):
            super(bloco_0.registro_0120, self).__init__()
            self.REG = '0120'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.MES_DISPENSA = ''
            self.INF_COMP = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'MES_DISPENSA': {'tipo': 'C', 'tamanho': 6, 'fixa_tamanho': True},
                'INF_COMP': {'tipo': 'C', 'tamanho': 90, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'MES_DISPENSA', 'INF_COMP')
            self.formato = self.get_formato()

    class registro_0140(TrackedAttributesClass):
        """
        REGISTRO 0140: IDENTIFICAÇÃO DE PERÍODOS DISPENSADOS DA ESCRITURAÇÃO FISCAL DIGITAL DAS
        CONTRIBUIÇÕES – EFD-CONTRIBUIÇÕES
        Registro opcional, específico para a pessoa jurídica informar os meses em que não tenha
        realizado operações representativas de receitas auferidas ou recebidas, e operações com
        direito a crédito (ensejando a dispensa de transmissão de EFD-Contribuições nesses meses),
        a ser apresentado na escrituração referente ao período de apuração de dezembro de cada
        ano-calendário ou no mês em que ocorreu a extinção, incorporação, fusão e cisão total ou
        parcial. Referido registro ainda não está disponibilizado para preenchimento,
        """

        _order = []

        def __init__(self):
            super(bloco_0.registro_0140, self).__init__()
            self.REG = '0140'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_EST = ''
            self.NOME = ''
            self.CNPJ = ''
            self.UF = ''
            self.IE = ''
            self.COD_MUN = ''
            self.IM = ''
            self.SUFRAMA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_EST': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'NOME': {'tipo': 'C', 'tamanho': 100, 'fixa_tamanho': False},
                'CNPJ': {'tipo': 'N', 'tamanho': 14, 'fixa_tamanho': True},
                'UF': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'IE': {'tipo': 'C', 'tamanho': 14, 'fixa_tamanho': False},
                'COD_MUN': {'tipo': 'N', 'tamanho': 7, 'fixa_tamanho': True},
                'IM': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                'SUFRAMA': {'tipo': 'C', 'tamanho': 9, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'COD_EST', 'NOME', 'CNPJ', 'UF', 'IE', 'COD_MUN', 'IM',
                               'SUFRAMA')
            self.formato = self.get_formato()

    class registro_0145(TrackedAttributesClass):
        """
        REGISTRO 0145: REGIME DE APURAÇÃO DA CONTRIBUIÇÃO PREVIDENCIÁRIA SOBRE A RECEITA BRUTA
        Este registro servirá para identificar a obrigatoriedade de escrituração da Contribuição
        Previdenciária sobre Receitas, no Bloco “P”. O Registro “0145” tem natureza meramente
        informativa, não transferindo nem recebendo valores de quaisquer outro registro da
        escrituração. Deve escriturar o Registro “0145” a pessoa jurídica que tenha auferido
        receita das atividades de serviços ou da fabricação de produtos, relacionados nos art. 7o e
        8o da Lei no 12.546/2011, respectivamente.
        """

        _order = []

        def __init__(self):
            super(bloco_0.registro_0145, self).__init__()
            self.REG = '0145'
            self.nivel_h = 3
            self.pai = '0001'
            self.ocorrencia = '1'
            self.COD_INC_TRIB = ''
            self.VL_REC_TOT = ''
            self.VL_REC_ATIV = ''
            self.VL_REC_DEMAIS_ATIV = ''
            self.INFO_COMPL = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_INC_TRIB': {'tipo': 'N', 'tamanho': 1, 'fixa_tamanho': True},
                'VL_REC_TOT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_REC_ATIV': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_REC_DEMAIS_ATIV': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False,
                                       'decimal': 2},
                'INFO_COMPL': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_INC_TRIB', 'VL_REC_TOT', 'VL_REC_ATIV',
                               'VL_REC_DEMAIS_ATIV', 'INFO_COMPL')
            self.formato = self.get_formato()

    class registro_0150(TrackedAttributesClass):
        """
        REGISTRO 0150: TABELA DE CADASTRO DO PARTICIPANTE
        Registro utilizado para informações cadastrais das pessoas físicas ou jurídicas envolvidas
        nas transações comerciais com o estabelecimento, no período. Participantes sem movimentação
        no período não devem ser informados neste registro.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0150, self).__init__()
            self.REG = '0150'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_PART = ''  # Código de identificação do participante no arquivo.
            self.NOME = ''  # Nome pessoal ou empresarial do participante.
            self.COD_PAIS = ''  # Código do país do participante, conforme a tabela indicada no
            # item 3.2.1
            self.CNPJ = ''  # CNPJ do participante.
            self.CPF = ''  # CPF do participante.
            self.IE = ''  # Inscrição Estadual do participante.
            self.COD_MUN = ''  # Código do município, conforme a tabela IBGE
            self.SUFRAMA = ''  # Número de inscrição do participante na SUFRAMA.
            self.END = ''  # Logradouro e endereço do imóvel
            self.NUM = ''  # Número do imóvel
            self.COMPL = ''  # Dados complementares do endereço
            self.BAIRRO = ''  # Bairro em que o imóvel está situado
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_PART': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'NOME': {'tipo': 'C', 'tamanho': 100, 'fixa_tamanho': False},
                'COD_PAIS': {'tipo': 'N', 'tamanho': 5, 'fixa_tamanho': False},
                'CNPJ': {'tipo': 'N', 'tamanho': 14, 'fixa_tamanho': True},
                'CPF': {'tipo': 'N', 'tamanho': 11, 'fixa_tamanho': True},
                'IE': {'tipo': 'C', 'tamanho': 14, 'fixa_tamanho': False},
                'COD_MUN': {'tipo': 'N', 'tamanho': 7, 'fixa_tamanho': True},
                'SUFRAMA': {'tipo': 'C', 'tamanho': 9, 'fixa_tamanho': True},
                'END': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'NUM': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                # nao especificado na documentacao serah sempre igual a zero
                'COMPL': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'BAIRRO': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_PART', 'NOME', 'COD_PAIS', 'CNPJ', 'CPF', 'IE',
                               'COD_MUN', 'SUFRAMA', 'END', 'NUM', 'COMPL', 'BAIRRO')
            self.formato = self.get_formato()

    class registro_0190(TrackedAttributesClass):
        """
        REGISTRO 0190: IDENTIFICAÇÃO DAS UNIDADES DE MEDIDA
        Este registro tem por objetivo descrever as unidades de medidas utilizadas no arquivo
        digital. Não podem ser informados dois ou mais registros com o mesmo código de unidade de
        medida. Somente devem constar as unidades de medidas informadas nos demais blocos.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0190, self).__init__()
            self.REG = '0190'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.UNID = ''  # Código da unidade de medida
            self.DESCR = ''  # Descrição da unidade de medida
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'UNID': {'tipo': 'C', 'tamanho': 6, 'fixa_tamanho': False},
                'DESCR': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'UNID', 'DESCR')
            self.formato = self.get_formato()

    class registro_0200(TrackedAttributesClass):
        """
        REGISTRO 0200: TABELA DE IDENTIFICAÇÃO DO ITEM (PRODUTO E SERVIÇOS)
        Este registro tem por objetivo informar mercadorias, serviços, produtos ou quaisquer outros
        itens concernentes às transações fiscais. Quando ocorrer alteração somente na descrição do
        item, sem que haja descaracterização deste, ou seja, criação de um novo item, a alteração
        deve constar no registro 0205. Só devem ser apresentados itens referenciados nos demais
        blocos.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0200, self).__init__()
            self.REG = '0200'
            self.nivel_h = 3
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_ITEM = ''  # Código do item
            self.DESCR_ITEM = ''  # Descrição do item
            self.COD_BARRA = ''  # Representação alfanumérico do código de barra do produto,
            # se houver
            self.COD_ANT_ITEM = ''  # Código anterior do item com relação à última informação
            # apresentada.
            self.UNID_INV = ''  # Unidade de medida utilizada na quantificação de estoques.
            self.TIPO_ITEM = ''  # Tipo do item – Atividades Industriais, Comerciais e Serviços:
            self.COD_NCM = ''  # Código da Nomenclatura Comum do Mercosul
            self.EX_IPI = ''  # Código EX, conforme a TIPI
            self.COD_GEN = ''  # Código do gênero do item, conforme a Tabela 4.2.1
            self.COD_LST = ''  # Código do serviço conforme lista do Anexo I da Lei Complementar
            # Federal no 116/03.
            self.ALIQ_ICMS = ''  # Alíquota de ICMS aplicável ao item nas operações internas.
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': True},
                'DESCR_ITEM': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                'COD_BARRA': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                'COD_ANT_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'UNID_INV': {'tipo': 'C', 'tamanho': 6, 'fixa_tamanho': False},
                'TIPO_ITEM': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'COD_NCM': {'tipo': 'C', 'tamanho': 8, 'fixa_tamanho': False},
                'EX_IPI': {'tipo': 'C', 'tamanho': 3, 'fixa_tamanho': False},
                'COD_GEN': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'COD_LST': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': False},
                'ALIQ_ICMS': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False, 'decimal': 2},
            }
            self.fieldnames = ('REG', 'COD_ITEM', 'DESCR_ITEM', 'COD_BARRA', 'COD_ANT_ITEM',
                               'UNID_INV', 'TIPO_ITEM', 'COD_NCM', 'EX_IPI', 'COD_GEN', 'COD_LST',
                               'ALIQ_ICMS')
            self.formato = self.get_formato()

    class registro_0205(TrackedAttributesClass):
        """
        REGISTRO 0205: ALTERAÇÃO DO ITEM
        Este registro tem por objetivo informar alterações ocorridas na descrição do produto, desde
        que não o descaracterize ou haja modificação que o identifique como sendo novo produto,
        caso não tenha ocorrido movimentação no período da alteração do item, deverá ser informada
        no primeiro período em que houver movimentação do item. Deverá ser ainda informado quando
        ocorrer alteração na codificação do produto. Não podem ser informados dois ou mais
        registros com sobreposição de períodos.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0205, self).__init__()
            self.REG = '0205'
            self.nivel_h = 3
            self.pai = '0200'
            self.ocorrencia = 'N'
            self.DESCR_ANT_ITEM = ''  # Descrição anterior do item
            self.DT_INI = ''  # Data inicial de utilização da descrição do item
            self.DT_FIM = ''  # Data final de utilização da descrição do item
            self.COD_ANT_ITEM = ''  # Código anterior do item com relação à última informação
            # apresentada.
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'DESCR_ANT_ITEM': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                'DT_INI': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_FIM': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'COD_ANT_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'DESCR_ANT_ITEM', 'DT_INI', 'DT_FIM', 'COD_ANT_ITEM')
            self.formato = self.get_formato()

    class registro_0206(TrackedAttributesClass):
        """
        REGISTRO 0206: CÓDIGO DE PRODUTO CONFORME TABELA PUBLICADA PELA ANP (COMBUSTÍVEIS)
        Este registro tem por objetivo informar o código correspondente ao produto constante na
        Tabela da Agência Nacional de Petróleo (ANP) para os produtos denominados “Combustíveis”.
        Deve ser apresentado apenas pelos contribuintes produtores, importadores e distribuidores
        de combustíveis.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0206, self).__init__()
            self.REG = '0206'
            self.nivel_h = 4
            self.pai = '0200'
            self.ocorrencia = '1'
            self.COD_COMB = ''  # Código do combustível, conforme tabela publicada pela ANP
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_COMB': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_COMB')
            self.formato = self.get_formato()

    class registro_0208(TrackedAttributesClass):
        """
        REGISTRO 0208: CÓDIGO DE GRUPOS POR MARCA COMERCIAL – REFRI (BEBIDAS FRIAS).
        Este registro deve ser preenchido pela pessoa jurídica industrial ou importadora de bebidas
        frias (cerveja, refrigerantes, águas, preparações compostas não alcoólicas, etc), optante
        do Regime Especial de Apuração da Contribuição para o PIS/Pasep e da Cofins por litro de
        produto, conforme as alíquotas específicas por produto e marcas comerciais estabelecidas
        pelo Poder Executivo, nos termos da Lei no 10.833, de 2003.
        """

        _order = []

        def __init__(self):
            super(bloco_0.registro_0208, self).__init__()
            self.REG = '0208'
            self.nivel_h = 3
            self.pai = '0200'
            self.ocorrencia = '1'
            self.COD_TAB = ''  # Código indicador da Tabela de Incidência, conforme Anexo III do
            # Decreto no 6.707/08
            self.COD_GRU = ''
            self.MARCA_COM = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_TAB': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': False},
                'COD_GRU': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': False},
                'MARCA_COM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_TAB', 'COD_GRU', 'MARCA_COM')
            self.formato = self.get_formato()

    class registro_0400(TrackedAttributesClass):
        """
        REGISTRO 0400: TABELA DE NATUREZA DA OPERAÇÃO/PRESTAÇÃO
        Este registro tem por objetivo codificar os textos das diferentes naturezas da
        operação/prestação discriminadas nos documentos fiscais. Esta codificação e suas descrições
        são livremente criadas e mantidas pelo contribuinte.
        Este registro não se refere a CFOP. Algumas empresas utilizam outra classificação além das
        apresentados nos CFOP. Esta codificação permite informar estes agrupamentos próprios.
        Não podem ser informados dois ou mais registros com o mesmo conteúdo no campo COD_NAT
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0400, self).__init__()
            self.REG = '0400'
            self.nivel_h = 3
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_NAT = ''  # Código da natureza da operação/prestação
            self.DESCR_NAT = ''  # Descrição da natureza da operação/prestação
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_NAT': {'tipo': 'C', 'tamanho': 10, 'fixa_tamanho': False},
                'DESCR_NAT': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_NAT', 'DESCR_NAT')
            self.formato = self.get_formato()


    class registro_0450(TrackedAttributesClass):
        """
        REGISTRO 0450: TABELA DOCUMENTO FISCAL DE INFORMAÇÃO COMPLEMENTAR DO DOCUMENTO FISCAL
        Este registro tem por objetivo codificar todas as informações complementares dos documentos
        fiscais, exigidas pela legislação fiscal. Estas informações constam no campo
        “Dados Adicionais” dos documentos fiscais.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0450, self).__init__()
            self.REG = '0450'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_INF = ''  # Código da informação complementar do documento fiscal
            self.TXT = ''  # Texto livre da informação complementar existente no documento fiscal,
            # inclusive espécie de normas legais, poder normativo, número, capitulação, data e
            # demais referências pertinentes com indicação referentes ao tributo.
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_INF': {'tipo': 'C', 'tamanho': 6, 'fixa_tamanho': False},
                'TXT': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_INF', 'TXT')
            self.formato = self.get_formato()

    class registro_0500(TrackedAttributesClass):
        """
        REGISTRO 0500: PLANO DE CONTAS CONTÁBEIS
        Este registro tem o objetivo de identificar as contas contábeis utilizadas pelo
        contribuinte informante em sua Contabilidade Geral, no que se refere às contas
        referenciadas no registro 0300. Não podem ser informados dois ou mais registros com a mesma
        combinação de conteúdo nos campos DT_ALT e COD_CTA.
        """

        _order = []

        def __init__(self):
            super(bloco_0.registro_0500, self).__init__()
            self.REG = '0500'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.DT_ALT = ''  # Data da inclusão/alteração
            self.COD_NAT_CC = ''  # Código da natureza da conta/grupo de contas:
            # 01 - Contas de ativo; 02 - Contas de passivo;03 - Patrimônio líquido;
            # 04 - Contas de resultado;05 - Contas de compensação;09 - Outras.
            self.IND_CTA = ''  # Indicador do tipo de conta: S - Sintética (grupo de contas);
            # A - Analítica (conta).
            self.NIVEL = ''  # Nível da conta analítica/grupo de contas.
            self.COD_CTA = ''  # Código da conta analítica/grupo de contas.
            self.NOME_CTA = ''  # Nome da conta analítica/grupo de contas.
            self.COD_CTA_REF = ''
            self.CNPJ_EST = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'DT_ALT': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': True},
                'COD_NAT_CC': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'IND_CTA': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'NIVEL': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': False},
                'COD_CTA': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': False},
                'NOME_CTA': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': False},
                'COD_CTA_REF': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': False},
                'CNPJ_EST': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': False},

            }
            self.fieldnames = ('REG', 'DT_ALT', 'COD_NAT_CC', 'IND_CTA', 'NIVEL', 'COD_CTA',
                               'NOME_CTA', 'COD_CTA_REF', 'CNPJ_EST')
            self.formato = self.get_formato()

    class registro_0600(TrackedAttributesClass):
        """
        REGISTRO 0600: CENTRO DE CUSTOS
        Este registro tem o objetivo de identificar os centros de custos referenciados no registro
        0305.
        Não podem ser informados dois ou mais registros com a mesma combinação de conteúdo nos
        campos DT_ALT e COD_CCUS.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0600, self).__init__()
            self.REG = '0600'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.DT_ALT = ''  # Data da inclusão/alteração.
            self.COD_CCUS = ''  # Código do centro de custos.
            self.CCUS = ''  # Nome do centro de custos.
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'DT_ALT': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': True},
                'COD_CCUS': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'CCUS': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'DT_ALT', 'COD_CCUS', 'CCUS')
            self.formato = self.get_formato()

    class registro_0990(TrackedAttributesClass):
        """
        REGISTRO 0990: ENCERRAMENTO DO BLOCO 0
        Este registro tem por objetivo identificar o encerramento do bloco 0 e informar a
        quantidade de linhas (registros) existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0990, self).__init__()
            self.REG = '0990'
            self.nivel_h = 1
            self.pai = '0000'
            self.ocorrencia = '1'
            self.QTD_LIN_0 = ''  # Quantidade total de linhas do Bloco 0
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'QTD_LIN_0': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False}
            }
            self.fieldnames = ('REG', 'QTD_LIN_0')
            self.formato = self.get_formato()
