# -*- coding: utf-8 -*-

from ..utils import *


class bloco_a(TrackedAttributesClass):
    """
    BLOCO A: DOCUMENTOS FISCAIS - SERVIÇOS (NÃO SUJEITOS AO ICMS)
    """

    class registro_A001(TrackedAttributesClass):
        """
        REGISTRO A001: ABERTURA DO BLOCO A
        Este registro deve ser gerado para abertura do Bloco A, indicando se há registros de informações no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_a.registro_A001, self).__init__()
            self.REG = 'A001'  # Texto fixo contendo.
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = '0'  # Indicador de movimento:0- Bloco com dados informados;1- Bloco sem dados informados.
            self.registro_A010 = []
            self.registro_A100 = []
            self.registro_A110 = []
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'IND_MOV': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()


    class registro_A010(TrackedAttributesClass):
        """
        REGISTRO A010: IDENTIFICAÇÃO DO ESTABELECIMENTO
        Este registro tem o objetivo de prestar informações sobre o CIAP:
        """
        _order = []

        def __init__(self):
            super(bloco_a.registro_A010, self).__init__()
            self.REG = 'A010'  # Texto fixo contendo.
            self.nivel_h = 2  # nível
            self.pai = 'A001'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.CNPJ = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CNPJ': {'tipo': 'N', 'tamanho': 14, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'CNPJ')
            self.formato = self.get_formato()


    class registro_A100(TrackedAttributesClass):
        """
        REGISTRO A100: DOCUMENTO - NOTA FISCAL DE SERVIÇO
        """

        _order = []

        def __init__(self):
            super(bloco_a.registro_A100, self).__init__()
            self.REG = 'A100'  # Texto fixo contendo.
            self.nivel_h = 3  # nível
            self.pai = 'A001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_OPER = ''
            self.IND_EMIT = ''
            self.COD_PART = ''
            self.COD_SIT = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC = ''
            self.CHV_NFSE = ''
            self.DT_DOC = ''
            self.DT_EXE_SERV = ''
            self.VL_DOC = ''
            self.IND_PGTO = ''
            self.VL_DESC = ''
            self.VL_BC_PIS = ''
            self.VL_PIS = ''
            self.VL_BC_COFINS = ''
            self.VL_COFINS = ''
            self.VL_PIS_RET = ''
            self.VL_COFINS_RET = ''
            self.VL_ISS = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'IND_OPER': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'IND_EMIT': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'COD_PART': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'COD_SIT': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'SER': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'SUB': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'NUM_DOC': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'CHV_NFSE': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'DT_DOC': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_EXE_SERV': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': True},
                'VL_DOC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'IND_PGTO': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_PIS_RET': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_COFINS_RET': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_ISS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2}

            }
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_SIT', 'SER', 'SUB',
                               'NUM_DOC', 'CHV_NFSE', 'DT_DOC', 'DT_EXE_SERV', 'VL_DOC', 'IND_PGTO',
                               'VL_DESC', 'VL_BC_PIS', 'VL_PIS', 'VL_BC_COFINS', 'VL_COFINS',
                               'VL_PIS_RET', 'VL_COFINS_RET', 'VL_ISS')
            self.formato = self.get_formato()

    class registro_A110(TrackedAttributesClass):
        """
        REGISTRO A110: COMPLEMENTO DO DOCUMENTO - INFORMAÇÃO COMPLEMENTAR DA NF
        Este registro tem por objetivo identificar os dados contidos no campo Informações Complementares da Nota Fiscal, que
        sejam de interesse do Fisco ou conforme disponha a legislação, e que estejam explicitamente citadas no documento
        Fiscal, tais como: forma de pagamento, local da prestação/execução do serviço, operação realizada com suspensão das
        contribuições sociais, etc.
        """

        _order = []

        def __init__(self):
            super(bloco_a.registro_A110, self).__init__()
            self.REG = 'A110'  # Texto fixo contendo.
            self.nivel_h = 4  # nível
            self.pai = 'A001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_INF = ''
            self.TXT_COMPL = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_INF': {'tipo': 'C', 'tamanho': 6, 'fixa_tamanho': False},
                'TXT_COMPL': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_INF', 'TXT_COMPL')
            self.formato = self.get_formato()

    class registro_A111(TrackedAttributesClass):
        """
        REGISTRO A111: PROCESSO REFERENCIADO
        """
        _order = []

        def __init__(self):
            super(bloco_a.registro_A111, self).__init__()
            self.REG = 'A111'  # Texto fixo contendo.
            self.nivel_h = 4  # nível
            self.pai = 'A001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_PROC': {'tipo': 'C', 'tamanho': 15, 'fixa_tamanho': False},
                'IND_PROC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'NUM_PROC', 'IND_PROC')
            self.formato = self.get_formato()

    class registro_A120(TrackedAttributesClass):
        """
        REGISTRO A120: INFORMAÇÃO COMPLEMENTAR - OPERAÇÕES DE IMPORTAÇÃO
        Este registro tem por objetivo informar detalhes das operações de importação de serviços com direito a crédito, referentes
        a documento fiscal escriturado em A100 e que no registro filho A170 conste CST_PIS ou CST_COFINS gerador de
        crédito (CST 50 a 56), bem como conste ser o registro A170 originário de operação de importação (campo IND_ORIG_CRED = 1).
        """

        _order = []

        def __init__(self):
            super(bloco_a.registro_A120, self).__init__()
            self.REG = 'A120'  # Texto fixo contendo.
            self.nivel_h = 4  # nível
            self.pai = 'A001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.VL_TOT_SERV = ''
            self.VL_BC_PIS = ''
            self.VL_PIS_IMP = ''
            self.DT_PAG_PIS = ''
            self.VL_BC_COFINS = ''
            self.VL_COFINS_IMP = ''
            self.DT_PAG_COFINS = ''
            self.LOC_EXE_SERV = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_TOT_SERV': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_PIS_IMP': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'DT_PAG_PIS': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_COFINS_IMP': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'DT_PAG_COFINS': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'LOC_EXE_SERV': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'VL_TOT_SERV', 'VL_BC_PIS', 'VL_BC_PIS', 'DT_PAG_PIS',
                               'VL_BC_COFINS', 'VL_COFINS_IMP', 'DT_PAG_COFINS', 'LOC_EXE_SERV')
            self.formato = self.get_formato()

    class registro_A170(TrackedAttributesClass):
        """
        REGISTRO A170: COMPLEMENTO DO DOCUMENTO - ITENS DO DOCUMENTO
        Registro obrigatório para discriminar os itens da nota fiscal de serviço emitida pela pessoa jurídica ou por terceiros.
        Não podem ser informados para um mesmo documento fiscal, dois ou mais registros com o mesmo conteúdo no campo
        NUM_ITEM.
        """

        _order = []

        def __init__(self):
            super(bloco_a.registro_A170, self).__init__()
            self.REG = 'A170'  # Texto fixo contendo.
            self.nivel_h = 4  # nível
            self.pai = 'A100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''
            self.COD_ITEM = ''
            self.DESCR_COMPL = ''
            self.VL_ITEM = ''
            self.VL_DESC = ''
            self.NAT_BC_CRED = ''
            self.IND_ORIG_CRED = ''
            self.CST_PIS = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.CST_COFINS = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.COD_CCUS = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_ITEM': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': False},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'DESCR_COMPL': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'NAT_BC_CRED': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'IND_ORIG_CRED': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'CST_PIS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'CST_COFINS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False, 'decimal': 2},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'COD_CCUS': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM', 'DESCR_COMPL', 'VL_ITEM',
                               'VL_DESC', 'NAT_BC_CRED', 'IND_ORIG_CRED', 'CST_PIS', 'VL_BC_PIS',
                               'ALIQ_PIS', 'VL_PIS', 'CST_COFINS', 'VL_BC_COFINS', 'ALIQ_COFINS',
                               'VL_COFINS', 'COD_CTA', 'COD_CCUS')
            self.formato = self.get_formato()

    class registro_A990(TrackedAttributesClass):
        """
        REGISTRO A990: ENCERRAMENTO DO BLOCO A
        Este registro destina-se a identificar o encerramento do bloco A e informar a quantidade de linhas (registros)
        existentes no bloco.
        """

        _order = []

        def __init__(self):
            super(bloco_a.registro_A990, self).__init__()
            self.REG = 'A990'
            self.nivel_h = 1
            self.pai = '0000'
            self.ocorrencia = '1'
            self.QTD_LIN_A = ''  # Quantidade total de linhas do Bloco A
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'QTD_LIN_0': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False}
            }
            self.fieldnames = ('REG', 'QTD_LIN_A')
            self.formato = self.get_formato()
