# -*- coding: utf-8 -*-

from ..utils import *


class bloco_m(TrackedAttributesClass):
    """
        BLOCO M – APURAÇÃO DA CONTRIBUIÇÃO E CRÉDITO DO PIS/PASEP
        E DA COFINS
        Os registros componentes dos Blocos “M” são escriturados na visão da empresa, diferentemente dos registros
        informados nos Blocos “A”, “C”, “D” e “F” que são informados na visão de cada estabelecimento da pessoa jurídica que
        realizou as operações gerados de contribuições sociais ou de créditos.
    """

    class registro_M001(TrackedAttributesClass):
        """
            REGISTRO M001: ABERTURA DO BLOCO M
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M001, self).__init__()
            self.REG = 'M001'  # Texto fixo contendo.
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = ''  # Indicador de movimento:0- Bloco com dados informados;1- Bloco sem dados informados.
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_M100(TrackedAttributesClass):
        """
        REGISTRO M100: CRÉDITO DE PIS/PASEP RELATIVO AO PERÍODO
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M100, self).__init__()
            self.REG = 'M100'  # Texto fixo contendo.
            self.nivel_h = 2  # nível
            self.pai = 'M001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_CRED = ''
            self.IND_CRED_ORI = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.QUANT_BC_PIS = ''
            self.ALIQ_PIS_QUANT = ''
            self.VL_CRED = ''
            self.VL_AJUS_ACRES = ''
            self.VL_AJUS_REDUC = ''
            self.VL_CRED_DIF = ''
            self.VL_CRED_DISP = ''
            self.IND_DESC_CRED = ''
            self.VL_CRED_DESC = ''
            self.SLD_CRED = ''
            self.fieldnames = ('REG', 'COD_CRED', 'IND_CRED_ORI', 'VL_BC_PIS', 'ALIQ_PIS',
                               'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_CRED', 'VL_AJUS_ACRES',
                               'VL_AJUS_REDUC', 'VL_CRED_DIF', 'VL_CRED_DISP', 'IND_DESC_CRED',
                               'VL_CRED_DESC', 'SLD_CRED')
            self.formato = self.get_formato()
            
    class registro_M105(TrackedAttributesClass):
        """
            REGISTRO M105: DETALHAMENTO DA BASE DE CALCULO DO CRÉDITO APURADO
            NO PERÍODO – PIS/PASEP
            """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M105, self).__init__()
            self.REG = 'M105'  # Texto fixo contendo.
            self.nivel_h = 3  # nível
            self.pai = 'M001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NAT_BC_CRED = ''
            self.CST_PIS = ''
            self.VL_BC_PIS_TOT = ''
            self.VL_BC_PIS_CUM = ''
            self.VL_BC_PIS_NC = ''
            self.VL_BC_PIS = ''
            self.QUANT_BC_PIS_TOT = ''
            self.QUANT_BC_PIS = ''
            self.DESC_CRED = ''
            self.fieldnames = ('REG', 'NAT_BC_CRED', 'CST_PIS', 'VL_BC_PIS_TOT', 'VL_BC_PIS_CUM', 
                               'VL_BC_PIS_NC', 'VL_BC_PIS', 'QUANT_BC_PIS_TOT', 'QUANT_BC_PIS', 
                               'DESC_CRED')
            self.formato = self.get_formato()
         
    class registro_M110(TrackedAttributesClass):
        """
            REGISTRO M110: AJUSTES DO CRÉDITO DE PIS/PASEP APURADO
            Registro a ser preenchido caso a pessoa jurídica tenha de proceder a ajustes de créditos escriturados no período,
            decorrentes de ação judicial, de processo de consulta, da legislação tributária das contribuições sociais, de estorno ou de
            outras situações.
            Este registro será utilizado pela pessoa jurídica para detalhar as informações prestadas nos campos 09 e 10 do registro pai
            M100.
            """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M110, self).__init__()
            self.REG = 'M110'  # Texto fixo contendo.
            self.nivel_h = 3  # nível
            self.pai = 'M100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_AJ = ''
            self.VL_AJ = ''
            self.COD_AJ = ''
            self.NUM_DOC = ''
            self.DESCR_AJ = ''
            self.DT_REF = ''


    class registro_M200(TrackedAttributesClass):
        """
      REGISTRO M200: CONSOLIDAÇÃO DA CONTRIBUIÇÃO PARA O PIS/PASEP DO  PERÍODO
        Neste registro serão consolidadas as contribuições sociais apuradas no período da escrituração, nos regimes não-
        cumulativo e cumulativo, bem como procedido ao desconto dos créditos não cumulativos apurados no próprio período,
        dos créditos apurados em períodos anteriores, dos valores retidos na fonte e de outras deduções previstas em Lei,
        demonstrando em seu final os valores devidos a recolher.
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M200, self).__init__()
            self.REG = 'M200'  # Texto fixo contendo.
            self.nivel_h = 4  # nível
            self.pai = 'M001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.VL_TOT_CONT_NC_PER = ''
            self.VL_TOT_CRED_DESC = ''
            self.VL_TOT_CRED_DESC_ANT = ''
            self.VL_TOT_CONT_NC_DEV = ''
            self.VL_RET_NC = ''
            self.VL_OUT_DED_NC = ''
            self.VL_CONT_NC_REC = ''
            self.VL_TOT_CONT_CUM_PER = ''
            self.VL_RET_CUM = ''
            self.VL_OUT_DED_CUM = ''
            self.VL_CONT_CUM_REC = ''
            self.VL_TOT_CONT_REC = ''
            self.fieldnames = ('REG', 'VL_TOT_CONT_NC_PER', 'VL_TOT_CRED_DESC', 
                               'VL_TOT_CRED_DESC_ANT', 'VL_TOT_CONT_NC_DEV', 'VL_RET_NC', 
                               'VL_OUT_DED_NC', 'VL_CONT_NC_REC', 'VL_TOT_CONT_CUM_PER', 
                               'VL_RET_CUM', 'VL_OUT_DED_CUM', 'VL_CONT_CUM_REC', 'VL_TOT_CONT_REC')
            self.formato = self.get_formato()

    class registro_M205(TrackedAttributesClass):
        """
        REGISTRO M205: CONTRIBUIÇÃO PARA DETALHAMENTO
        POR CÓDIGO DE RECEITA
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M205, self).__init__()
            self.REG = 'M205'
            self.nivel_h = 5
            self.pai = 'M200'
            self.ocorrencia = 'N'
            self.NUM_CAMPO = ''
            self.COD_REC = ''
            self.VL_DEBITO = ''
            self.fieldnames = ('REG', 'NUM_CAMPO', 'COD_REC', 'VL_DEBITO')
            self.formato = self.get_formato()


    class registro_M210(TrackedAttributesClass):
        """
      REGISTRO M210: DETALHAMENTO DA CONTRIBUIÇÃO PARA O PIS/PASEP DO PERÍODO
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M210, self).__init__()
            self.REG = 'M210'  # Texto fixo contendo.
            self.nivel_h = 5  # nível
            self.pai = 'M200'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_CONT = ''
            self.VL_REC_BRT = ''
            self.VL_BC_CONT = ''
            self.ALIQ_PIS = ''
            self.QUANT_BC_PIS = ''
            self.ALIQ_PIS_QUANT = ''
            self.VL_CONT_APUR = ''
            self.VL_AJUS_ACRES = ''
            self.VL_AJUS_REDUC = ''
            self.VL_CONT_DIFER = ''
            self.VL_CONT_DIFER_ANT = ''
            self.VL_CONT_PER = ''
            self.fieldnames = ('REG', 'COD_CONT', 'VL_REC_BRT', 'VL_BC_CONT',
                               'ALIQ_PIS', 'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_CONT_APUR',
                               'VL_AJUS_ACRES', 'VL_AJUS_REDUC', 'VL_CONT_DIFER',
                               'VL_CONT_DIFER_ANT', 'VL_CONT_PER')
            self.formato = self.get_formato()
            
    class registro_M211(TrackedAttributesClass):
        """
        REGISTRO M211: SOCIEDADES COOPERATIVAS – COMPOSIÇÃO DA BASE DE
        CALCULO – PIS/PASEP
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M211, self).__init__()
            self.REG = 'M211'
            self.nivel_h = 4
            self.pai = 'M200'
            self.ocorrencia = '1'
            self.IND_TIP_COOP = ''
            self.VL_BC_CONT_ANT_EXC_COOP = ''
            self.VL_EXC_COOP_GER = ''
            self.VL_EXC_ESP_COOP = ''
            self.VL_BC_CONT = ''
            self.fieldnames = ('REG', 'IND_TIP_COOP', 'VL_BC_CONT_ANT_EXC_COOP', 'VL_EXC_COOP_GER', 
                               'VL_EXC_ESP_COOP', 'VL_BC_CONT')
            self.formato = self.get_formato()

    class registro_M400(TrackedAttributesClass):
        """
             REGISTRO M400: RECEITAS ISENTAS, NÃO ALCANÇADAS PELA INCIDÊNCIA DA
        CONTRIBUIÇÃO, SUJEITAS A ALÍQUOTA ZERO OU DE VENDAS COM SUSPENSÃO –
        PIS/PASEP
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M400, self).__init__()
            self.REG = 'M400'  # Texto fixo contendo.
            self.nivel_h = 5  # nível
            self.pai = 'M001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_PIS = ''
            self.VL_TOT_REC = ''
            self.COD_CTA = ''
            self.DESC_COMPL = ''
            self.fieldnames = ('REG', 'CST_PIS', 'VL_TOT_REC', 'COD_CTA', 'DESC_COMPL')
            self.formato = self.get_formato()

    class registro_M410(TrackedAttributesClass):
        """
           REGISTRO M410: DETALHAMENTO DAS RECEITAS ISENTAS, NÃO ALCANÇADAS
        PELA INCIDÊNCIA DA CONTRIBUIÇÃO, SUJEITAS A ALÍQUOTA ZERO OU DE
        VENDAS COM SUSPENSÃO – PIS/PASEP
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M410, self).__init__()
            self.REG = 'M410'  # Texto fixo contendo.
            self.nivel_h = 3  # nível
            self.pai = 'M400'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NAT_REC = ''
            self.VL_REC = ''
            self.COD_CTA = ''
            self.DESC_COMPL = ''
            self.fieldnames = ('REG', 'NAT_REC', 'VL_REC', 'COD_CTA', 'DESC_COMPL')
            self.formato = self.get_formato()

    class registro_M500(TrackedAttributesClass):
        """
            REGISTRO M500: CRÉDITO DE COFINS RELATIVO AO PERÍODO
            Este registro tem por finalidade realizar a consolidação do crédito relativo à Cofins apurado no período. Deve ser gerado
            um registro M500 especifico para cada tipo de crédito apurado (vinculados à receita tributada, vinculados à receita não
            tributada e vinculados à exportação), conforme a Tabela de tipos de créditos “Tabela 4.3.6”, bem como para créditos de
            operações próprias e créditos transferidos por eventos de sucessão.
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M500, self).__init__()
            self.REG = 'M500'  # Texto fixo contendo.
            self.nivel_h = 2  # nível
            self.pai = 'M001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_CRED = ''
            self.IND_CRED_ORI = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.QUANT_BC_COFINS = ''
            self.ALIQ_COFINS_QUANT = ''
            self.VL_CRED = ''
            self.VL_AJUS_ACRES = ''
            self.VL_AJUS_REDUC = ''
            self.VL_CRED_DIFER = ''
            self.VL_CRED_DISP = ''
            self.IND_DESC_CRED = ''
            self.VL_CRED_DESC = ''
            self.SLD_CRED = ''
            self.fieldnames = ('REG', 'COD_CRED', 'IND_CRED_ORI', 'VL_BC_COFINS', 'ALIQ_COFINS',
                               'QUANT_BC_COFINS', 'ALIQ_COFINS_QUANT', 'VL_CRED', 'VL_AJUS_ACRES',
                               'VL_AJUS_REDUC', 'VL_CRED_DIFER', 'VL_CRED_DISP', 'IND_DESC_CRED',
                               'VL_CRED_DESC', 'SLD_CRED')
            self.formato = self.get_formato()

    class registro_M505(TrackedAttributesClass):
        """
            REGISTRO M505: DETALHAMENTO DA BASE DE CALCULO DO CRÉDITO APURADO
            NO PERÍODO – COFINS
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M505, self).__init__()
            self.REG = 'M505'  # Texto fixo contendo.
            self.nivel_h = 3  # nível
            self.pai = 'M500'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NAT_BC_CRED = ''
            self.CST_COFINS = ''
            self.VL_BC_COFINS_TOT = ''
            self.VL_BC_COFINS_CUM = ''
            self.VL_BC_COFINS_NC = ''
            self.VL_BC_COFINS = ''
            self.QUANT_BC_COFINS_TOT = ''
            self.QUANT_BC_COFINS = ''
            self.DESC_CRED = ''

            self.fieldnames = ('REG', 'NAT_BC_CRED', 'CST_COFINS', 'VL_BC_COFINS_TOT', 'VL_BC_COFINS_CUM',
                               'VL_BC_COFINS_NC', 'VL_BC_COFINS', 'QUANT_BC_COFINS_TOT', 'QUANT_BC_COFINS',
                               'DESC_CRED')
            self.formato = self.get_formato()
            
    class registro_M600(TrackedAttributesClass):
        """
            REGISTRO M600: CONSOLIDAÇÃO DA CONTRIBUIÇÃO PARA A SEGURIDADE SOCIAL - COFINS DO PERÍODO
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M600, self).__init__()
            self.REG = 'M600'  # Texto fixo contendo.
            self.nivel_h = 5  # nível
            self.pai = 'M001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.VL_TOT_CONT_NC_PER = ''
            self.VL_TOT_CRED_DESC = ''
            self.VL_TOT_CRED_DESC_ANT = ''
            self.VL_TOT_CONT_NC_DEV = ''
            self.VL_RET_NC = ''
            self.VL_OUT_DED_NC = ''
            self.VL_CONT_NC_REC = ''
            self.VL_TOT_CONT_CUM_PER = ''
            self.VL_RET_CUM = ''
            self.VL_OUT_DED_CUM = ''
            self.VL_CONT_CUM_REC = ''
            self.VL_TOT_CONT_REC = ''
            self.fieldnames = ('REG', 'VL_TOT_CONT_NC_PER', 'VL_TOT_CRED_DESC',
                               'VL_TOT_CRED_DESC_ANT', 'VL_TOT_CONT_NC_DEV', 'VL_RET_NC',
                               'VL_OUT_DED_NC', 'VL_CONT_NC_REC', 'VL_TOT_CONT_CUM_PER',
                               'VL_RET_CUM', 'VL_OUT_DED_CUM', 'VL_CONT_CUM_REC', 'VL_TOT_CONT_REC')
            self.formato = self.get_formato()

    class registro_M605(TrackedAttributesClass):
        """
        REGISTRO M605:
        COFINS A RECOLHER – DETALHAMENTO POR CÓDIGO DE RECEITA
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M605, self).__init__()
            self.REG = 'M605'
            self.nivel_h = 5
            self.pai = 'M600'
            self.ocorrencia = 'N'
            self.NUM_CAMPO = ''
            self.COD_REC = ''
            self.VL_DEBITO = ''
            self.fieldnames = ('REG', 'NUM_CAMPO', 'COD_REC', 'VL_DEBITO')
            self.formato = self.get_formato()

    class registro_M610(TrackedAttributesClass):
        """
            REGISTRO M610: DETALHAMENTO DA CONTRIBUIÇÃO PARA A SEGURIDADE SOCIAL - COFINS DO PERÍODO
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M610, self).__init__()
            self.REG = 'M610'  # Texto fixo contendo.
            self.nivel_h = 5  # nível
            self.pai = 'M600'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_CONT = ''
            self.VL_REC_BRT = ''
            self.VL_BC_CONT = ''
            self.ALIQ_COFINS = ''
            self.QUANT_BC_COFINS = ''
            self.ALIQ_COFINS_QUANT = ''
            self.VL_CONT_APUR = ''
            self.VL_AJUS_ACRES = ''
            self.VL_AJUS_REDUC = ''
            self.VL_CONT_DIFER = ''
            self.VL_CONT_DIFER_ANT = ''
            self.VL_CONT_PER = ''
            self.fieldnames = ('REG', 'COD_CONT', 'VL_REC_BRT', 'VL_BC_CONT', 'ALIQ_COFINS',
                               'QUANT_BC_COFINS', 'ALIQ_COFINS_QUANT', 'VL_CONT_APUR',
                               'VL_AJUS_ACRES', 'VL_AJUS_REDUC', 'VL_CONT_DIFER',
                               'VL_CONT_DIFER_ANT', 'VL_CONT_PER')
            self.formato = self.get_formato()

    class registro_M611(TrackedAttributesClass):
        """
            REGISTRO M611: SOCIEDADES COOPERATIVAS – COMPOSIÇÃO DA BASE DE
            CALCULO – COFINS
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M611, self).__init__()
            self.REG = 'M611'
            self.nivel_h = 4
            self.pai = 'M600'
            self.ocorrencia = '1'
            self.IND_TIP_COOP = ''
            self.VL_BC_CONT_ANT_EXC_COOP = ''
            self.VL_EXC_COOP_GER = ''
            self.VL_EXC_ESP_COOP = ''
            self.VL_BC_CONT = ''
            self.fieldnames = ('REG', 'IND_TIP_COOP', 'VL_BC_CONT_ANT_EXC_COOP', 'VL_EXC_COOP_GER',
                               'VL_EXC_ESP_COOP', 'VL_BC_CONT')
            self.formato = self.get_formato()            

    class registro_M800(TrackedAttributesClass):
        """
            REGISTRO M800: RECEITAS ISENTAS, NÃO ALCANÇADAS PELA INCIDÊNCIA DA CONTRIBUIÇÃO, SUJEITAS A ALÍQUOTA ZERO
             OU DE VENDAS COM SUSPENSÃO –   COFINS
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M800, self).__init__()
            self.REG = 'M800'  # Texto fixo contendo.
            self.nivel_h = 5  # nível
            self.pai = 'M001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_COFINS = ''
            self.VL_TOT_REC = ''
            self.COD_CTA = ''
            self.DESC_COMPL = ''
            self.fieldnames = ('REG', 'CST_COFINS', 'VL_TOT_REC', 'COD_CTA', 'DESC_COMPL')
            self.formato = self.get_formato()

    class registro_M810(TrackedAttributesClass):
        """
            REGISTRO M810: DETALHAMENTO DAS RECEITAS ISENTAS, NÃO ALCANÇADAS
            PELA INCIDÊNCIA DA CONTRIBUIÇÃO, SUJEITAS A ALÍQUOTA ZERO OU DE
            VENDAS COM SUSPENSÃO – COFINS
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M810, self).__init__()
            self.REG = 'M810'  # Texto fixo contendo.
            self.nivel_h = 5  # nível
            self.pai = 'M800'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NAT_REC = ''
            self.VL_REC = ''
            self.COD_CTA = ''
            self.DESC_COMPL = ''
            self.fieldnames = ('REG', 'NAT_REC', 'VL_REC', 'COD_CTA', 'DESC_COMPL')
            self.formato = self.get_formato()


    class registro_M990(TrackedAttributesClass):
        """
        REGISTRO M990: ENCERRAMENTO DO BLOCO M
        Este registro deve ser gerado para o encerramento do Bloco G e indica o número total de registros existentes neste Bloco
        """
        _order = []

        def __init__(self):
            super(bloco_m.registro_M990, self).__init__()
            self.REG = 'M990'  # Texto fixo contendo.
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  #ocorrência por arquivo
            self.QTD_LIN_M = ''
            self.fieldnames = ('REG', 'QTD_LIN_M')
            self.formato = self.get_formato()
