# -*- coding: utf-8 -*-

from ..utils import *


class bloco_b(TrackedAttributesClass):
    """
    BLOCO B: ESCRITURACAO E APURACAO DO ISS
    """

    class registro_B001(TrackedAttributesClass):
        """
        REGISTRO B001: ABERTURA DO BLOCO B
        Este registro tem por objetivo identificar a abertura do bloco B, indicando se ha
        informacoes sobre documentos fiscais.
        Os estabelecimentos NAO domiciliados no Distrito Federal deverao informar apenas os
        registros B001 e B990 (abertura – bloco sem dados informados e fechamento).
        """
        _order = []

        def __init__(self):
            super(bloco_b.registro_B001, self).__init__()
            self.REG = 'B001'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_DAD = '0'  # Indicador de movimento: 0- Bloco com dados informados;
            # 1- Bloco sem dados informados.
            self.fieldnames = ('REG', 'IND_DAD')
            self.formato = self.get_formato()

    class registro_B990(TrackedAttributesClass):
        """
        REGISTRO B990: ENCERRAMENTO DO BLOCO B
        Este registro destina-se a identificar o encerramento do bloco B e informar a quantidade
        de linhas (registros) existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_b.registro_B990, self).__init__()
            self.REG = 'B990'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.QTD_LIN_B = ''
            self.fieldnames = ('REG', 'QTD_LIN_B')
            self.formato = self.get_formato()
