# -*- coding: utf-8 -*-


class TrackedAttributesClass(object):
    """Classe para manter a ordem em que estão declaradas os atributos da classe
       IMPORTANTE:

        @O atributo fieldnames, represenda o titulo do campo de cada registro, por tanto toda classe
         que Herdar de TrackedAttributesClass, e for um registro do sped, deve definir os campos
         que devem ser gerados para o registro do sped dentro de uma tupla.
         Estes campos, devem estar descritos justamente na ordem de colunas que o registro deve ser
         gerado.
         Classes que herdam de TrackedAttributesClass, e nao possuem a definicao deste campo,
         eh porque o registro nao esta implementado pelo ERP.

        @O Atributo, formato, deve ser definido por toda classe que Herda de TrackedAttributesClass
         pois sera o formato que cada registro deve ser gerado no arquivo. Este atributo deve
         ser daclarado no __init__ das classes tendo seu valor atribuido pelo metodo get_formato.
         Ele deve ser obrigatoriamente instanciado apos o atributo fieldnames, pois seu valor
         depende do deste atributo.

    """

    _order = []
    processos = []
    conta_registro = {'bloco_0': 0,
                      'bloco_a': 0,
                      'bloco_b': 0,
                      'bloco_c': 0,
                      'bloco_d': 0,
                      'bloco_e': 0,
                      'bloco_f': 0,
                      'bloco_g': 0,
                      'bloco_h': 0,
                      'bloco_k': 0,
                      'bloco_m': 0,
                      'bloco_p': 0,
                      'bloco_1': 0,
                      'bloco_9': 0}

    quantidade_registros = {}

    def __init__(self):
        self.REG = ""
        self.fieldnames = ()
        self.formato = ''

    def __setattr__(self, name, value):
        self._order.append(name)
        return super(TrackedAttributesClass, self).__setattr__(name, value)

    def remove_accents(self, text, cod='utf-8'):
        from unicodedata import normalize, category

        unicode_string = str(text)
        return ''.join(filter(lambda c: category(c) != 'Mn', normalize('NFKD', unicode_string)))

    def write_line(self):
        a = self.__dict__.copy()
        for x in a:
            if not isinstance(a[x], list):
                try:
                    value = self.remove_accents(a[x])
                except UnicodeEncodeError:
                    value = self.remove_accents(a[x].encode('utf-8'))
                if not value:
                    value = ''
                value = value.replace('|', ' ')
                a[x] = value.strip()
        try:
            self.conta_registro[self.get_registro(self.REG[0])] += 1
        except:
            self.conta_registro[self.get_registro(self.REG[0])] = 1
        if self.REG not in self.quantidade_registros:  # totaliza por registro
            self.quantidade_registros.update({self.REG: 1})
        else:
            self.quantidade_registros[self.REG] += 1
        a = self.delete_chaves_invalidas(a)
        self.processos.append('|%s|\r\n' % self.formato % a)
        return True

    @staticmethod
    def get_registro(inicio_bloco):
        blocos = {
            '0': 'bloco_0',
            'B': 'bloco_b',
            'C': 'bloco_c',
            'D': 'bloco_d',
            'E': 'bloco_e',
            'G': 'bloco_g',
            'H': 'bloco_h',
            'K': 'bloco_k',
            '1': 'bloco_1',
            '9': 'bloco_9',
            'A': 'bloco_a',
            'M': 'bloco_m',
            'P': 'bloco_p',
            'F': 'bloco_f',
        }
        return blocos.get(inicio_bloco)

    def delete_chaves_invalidas(self, dados):
        for dado in list(dados.keys()):
            if dado not in self.fieldnames:
                del(dados[dado])
        return dados

    def get_formato(self):
        f = str(self.fieldnames).strip('(').strip(')').replace("', ", ')s|').replace("'", '%(').\
                rstrip('%(') + ')s'
        return f
